@@ -39,6 +39,9 @@
 #include <sys/ioctl.h>
 #include <net/if.h>
 
+#include <sys/types.h>
+#include <ifaddrs.h>
+
 #ifndef G_OS_WIN32
 #include <sys/select.h>
 #include <netinet/in.h>
@@ -421,47 +424,36 @@ add_local_siocgifconf (GList **list)
 static void
 add_local_addrinfo (GList **list)
 {
-        char             hostbuf[BUFSIZ];
-        struct addrinfo *result;
-        struct addrinfo *res;
-        struct addrinfo  hints;
-
-        hostbuf[BUFSIZ-1] = '\0';
-        if (gethostname (hostbuf, BUFSIZ-1) != 0) {
-                g_debug ("%s: Could not get server hostname, using localhost", "gdm_peek_local_address_list");
-                snprintf (hostbuf, BUFSIZ-1, "localhost");
-        }
-
-        memset (&hints, 0, sizeof (hints));
-        hints.ai_family = AF_UNSPEC;
-        hints.ai_flags = AI_CANONNAME | AI_NUMERICHOST;
-
-
-        g_debug ("GdmAddress: looking up hostname: %s", hostbuf);
-        result = NULL;
-        if (getaddrinfo (hostbuf, NULL, &hints, &result) != 0) {
-                g_debug ("%s: Could not get address from hostname!", "gdm_peek_local_address_list");
+        struct ifaddrs *interface_addresses;
+	struct ifaddrs *interface_address;
 
+        if (getifaddrs (&interface_addresses) < 0) {
+                g_debug ("Could not get local interface addresses: %m");
                 return;
         }
 
-        for (res = result; res != NULL; res = res->ai_next) {
+        for (interface_address = interface_addresses; interface_address != NULL; interface_address = interface_address->ifa_next) {
                 GdmAddress *address;
+                int family;
 
-                g_debug ("family=%d sock_type=%d protocol=%d flags=0x%x canonname=%s\n",
-                         res->ai_family,
-                         res->ai_socktype,
-                         res->ai_protocol,
-                         res->ai_flags,
-                         res->ai_canonname ? res->ai_canonname : "(null)");
-                address = gdm_address_new_from_sockaddr (res->ai_addr, res->ai_addrlen);
+                if (interface_address->ifa_addr == NULL)
+                        continue;
+
+                family = interface_address->ifa_addr->sa_family;
+
+                if (family != AF_INET && family != AF_INET6)
+                        continue;
+
+                g_debug ("Local interface %s found (family: %s)\n",
+                         interface_address->ifa_name,
+                         family == AF_INET ? "AF_INET" : "AF_INET6");
+
+                address = gdm_address_new_from_sockaddr (interface_address->ifa_addr,
+                                                         (family == AF_INET) ? sizeof (struct sockaddr_in) : sizeof (struct sockaddr_in6));
                 *list = g_list_append (*list, address);
         }
 
-        if (result != NULL) {
-                freeaddrinfo (result);
-                result = NULL;
-        }
+        freeifaddrs (interface_addresses);
 }
 
 const GList *
