@@ -88,6 +88,42 @@ gdm_get_pwent_for_name (const char     *name,
         return (pwent != NULL);
 }
 
+gboolean
+gdm_get_pwent_for_uid (uid_t           uid,
+                       struct passwd **pwentp)
+{
+        struct passwd *pwent;
+
+        do {
+                errno = 0;
+                pwent = getpwuid (uid);
+        } while (pwent == NULL && errno == EINTR);
+
+        if (pwentp != NULL) {
+                *pwentp = pwent;
+        }
+
+        return (pwent != NULL);
+}
+
+gboolean
+gdm_get_grent_for_name (const char    *name,
+                        struct group **grentp)
+{
+        struct group *grent;
+
+        do {
+                errno = 0;
+                grent = getgrnam (name);
+        } while (grent == NULL && errno == EINTR);
+
+        if (grentp != NULL) {
+                *grentp = grent;
+        }
+
+        return (grent != NULL);
+}
+
 static gboolean
 gdm_get_grent_for_gid (gint           gid,
                        struct group **grentp)
@@ -787,10 +823,14 @@ gdm_shell_var_is_valid_char (gchar c, gboolean first)
                 g_ascii_isalpha (c);
 }
 
-/* This expands a string somewhat similar to how a shell would do it
-   if it was enclosed inside double quotes.  It handles variable
-   expansion like $FOO and ${FOO}, single-char escapes using \, and
-   non-escaped # at the begining of a word is taken as a comment and ignored */
+/*
+ * This expands a string somewhat similar to how a shell would do it
+ * if it was enclosed inside double quotes.  It handles variable
+ * expansion like $FOO and ${FOO}, single-char escapes using \, and
+ * non-escaped # at the begining of a word is taken as a comment and ignored
+
+ * The caller must free the returned string.
+ */
 char *
 gdm_shell_expand (const char *str,
                   GdmExpandVarFunc expand_var_func,
@@ -863,7 +903,7 @@ gdm_shell_expand (const char *str,
                         at_new_word = g_ascii_isspace (c);
                 }
         }
-        return g_string_free (s, FALSE);
+        return g_string_free_and_steal (s);
 }
 
 static gboolean
