@@ -36,7 +36,9 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
+#ifdef ENABLE_X11_SUPPORT
 #include <X11/Xauth.h>
+#endif
 
 #include "gdm-display-access-file.h"
 #include "gdm-common.h"
@@ -407,6 +409,7 @@ gdm_display_access_file_open (GdmDisplayAccessFile  *file,
         return TRUE;
 }
 
+#ifdef ENABLE_X11_SUPPORT
 static void
 _get_auth_info_for_display (GdmDisplayAccessFile *file,
                             GdmDisplay           *display,
@@ -429,9 +432,9 @@ _get_auth_info_for_display (GdmDisplayAccessFile *file,
                  *
                  * https://bugs.freedesktop.org/show_bug.cgi?id=43425
                  */
-                char localhost[HOST_NAME_MAX + 1] = "";
+                char localhost[_POSIX_HOST_NAME_MAX + 1] = "";
                 *family = FamilyLocal;
-                if (gethostname (localhost, HOST_NAME_MAX) == 0) {
+                if (gethostname (localhost, _POSIX_HOST_NAME_MAX) == 0) {
                         *address = g_strdup (localhost);
                 } else {
                         *address = g_strdup ("localhost");
@@ -449,6 +452,7 @@ _get_auth_info_for_display (GdmDisplayAccessFile *file,
         *name = g_strdup ("MIT-MAGIC-COOKIE-1");
         *name_length = strlen (*name);
 }
+#endif
 
 gboolean
 gdm_display_access_file_add_display (GdmDisplayAccessFile  *file,
@@ -496,6 +500,7 @@ gdm_display_access_file_add_display_with_cookie (GdmDisplayAccessFile  *file,
                                                  gsize                  cookie_size,
                                                  GError               **error)
 {
+#ifdef ENABLE_X11_SUPPORT
         Xauth auth_entry;
         gboolean display_added;
 
@@ -548,6 +553,9 @@ gdm_display_access_file_add_display_with_cookie (GdmDisplayAccessFile  *file,
         g_free (auth_entry.name);
 
         return display_added;
+#else
+    return FALSE;
+#endif
 }
 
 void
