@@ -33,10 +33,9 @@
 #include "gdm-display-store.h"
 #include "gdm-display.h"
 
-#define GDM_DISPLAY_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GDM_TYPE_DISPLAY_STORE, GdmDisplayStorePrivate))
-
-struct GdmDisplayStorePrivate
+struct _GdmDisplayStore
 {
+        GObject     parent;
         GHashTable *displays;
 };
 
@@ -102,9 +101,9 @@ gdm_display_store_error_quark (void)
 void
 gdm_display_store_clear (GdmDisplayStore    *store)
 {
-        g_return_if_fail (store != NULL);
+        g_return_if_fail (GDM_IS_DISPLAY_STORE (store));
         g_debug ("GdmDisplayStore: Clearing display store");
-        g_hash_table_remove_all (store->priv->displays);
+        g_hash_table_remove_all (store->displays);
 }
 
 static gboolean
@@ -122,7 +121,8 @@ gboolean
 gdm_display_store_remove (GdmDisplayStore    *store,
                           GdmDisplay         *display)
 {
-        g_return_val_if_fail (store != NULL, FALSE);
+        g_return_val_if_fail (GDM_IS_DISPLAY_STORE (store), FALSE);
+        g_return_val_if_fail (display != NULL, FALSE);
 
         gdm_display_store_foreach_remove (store,
                                           (GdmDisplayStoreFunc)remove_display,
@@ -163,13 +163,13 @@ gdm_display_store_foreach (GdmDisplayStore    *store,
 {
         FindClosure  closure;
 
-        g_return_if_fail (store != NULL);
+        g_return_if_fail (GDM_IS_DISPLAY_STORE (store));
         g_return_if_fail (func != NULL);
 
         closure.predicate = func;
         closure.user_data = user_data;
 
-        g_hash_table_foreach (store->priv->displays,
+        g_hash_table_foreach (store->displays,
                               (GHFunc) foreach_func,
                               &closure);
 }
@@ -180,10 +180,10 @@ gdm_display_store_lookup (GdmDisplayStore *store,
 {
         StoredDisplay *stored_display;
 
-        g_return_val_if_fail (store != NULL, NULL);
+        g_return_val_if_fail (GDM_IS_DISPLAY_STORE (store), NULL);
         g_return_val_if_fail (id != NULL, NULL);
 
-        stored_display = g_hash_table_lookup (store->priv->displays,
+        stored_display = g_hash_table_lookup (store->displays,
                                               id);
         if (stored_display == NULL) {
                 return NULL;
@@ -200,13 +200,13 @@ gdm_display_store_find (GdmDisplayStore    *store,
         StoredDisplay *stored_display;
         FindClosure    closure;
 
-        g_return_val_if_fail (store != NULL, NULL);
+        g_return_val_if_fail (GDM_IS_DISPLAY_STORE (store), NULL);
         g_return_val_if_fail (predicate != NULL, NULL);
 
         closure.predicate = predicate;
         closure.user_data = user_data;
 
-        stored_display = g_hash_table_find (store->priv->displays,
+        stored_display = g_hash_table_find (store->displays,
                                             (GHRFunc) find_func,
                                             &closure);
 
@@ -225,13 +225,13 @@ gdm_display_store_foreach_remove (GdmDisplayStore    *store,
         FindClosure closure;
         guint       ret;
 
-        g_return_val_if_fail (store != NULL, 0);
+        g_return_val_if_fail (GDM_IS_DISPLAY_STORE (store), 0);
         g_return_val_if_fail (func != NULL, 0);
 
         closure.predicate = func;
         closure.user_data = user_data;
 
-        ret = g_hash_table_foreach_remove (store->priv->displays,
+        ret = g_hash_table_foreach_remove (store->displays,
                                            (GHRFunc) find_func,
                                            &closure);
         return ret;
@@ -244,7 +244,7 @@ gdm_display_store_add (GdmDisplayStore *store,
         char          *id;
         StoredDisplay *stored_display;
 
-        g_return_if_fail (store != NULL);
+        g_return_if_fail (GDM_IS_DISPLAY_STORE (store));
         g_return_if_fail (display != NULL);
 
         gdm_display_get_id (display, &id, NULL);
@@ -252,7 +252,7 @@ gdm_display_store_add (GdmDisplayStore *store,
         g_debug ("GdmDisplayStore: Adding display %s to store", id);
 
         stored_display = stored_display_new (store, display);
-        g_hash_table_insert (store->priv->displays,
+        g_hash_table_insert (store->displays,
                              id,
                              stored_display);
 
@@ -273,7 +273,7 @@ gdm_display_store_class_init (GdmDisplayStoreClass *klass)
                 g_signal_new ("display-added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (GdmDisplayStoreClass, display_added),
+                              0,
                               NULL,
                               NULL,
                               g_cclosure_marshal_VOID__STRING,
@@ -283,27 +283,22 @@ gdm_display_store_class_init (GdmDisplayStoreClass *klass)
                 g_signal_new ("display-removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
-                              G_STRUCT_OFFSET (GdmDisplayStoreClass, display_removed),
+                              0,
                               NULL,
                               NULL,
                               g_cclosure_marshal_VOID__OBJECT,
                               G_TYPE_NONE,
                               1, G_TYPE_OBJECT);
-
-        g_type_class_add_private (klass, sizeof (GdmDisplayStorePrivate));
 }
 
 static void
 gdm_display_store_init (GdmDisplayStore *store)
 {
-
-        store->priv = GDM_DISPLAY_STORE_GET_PRIVATE (store);
-
-        store->priv->displays = g_hash_table_new_full (g_str_hash,
-                                                       g_str_equal,
-                                                       g_free,
-                                                       (GDestroyNotify)
-                                                       stored_display_free);
+        store->displays = g_hash_table_new_full (g_str_hash,
+                                                 g_str_equal,
+                                                 g_free,
+                                                 (GDestroyNotify)
+                                                 stored_display_free);
 }
 
 static void
@@ -311,14 +306,11 @@ gdm_display_store_finalize (GObject *object)
 {
         GdmDisplayStore *store;
 
-        g_return_if_fail (object != NULL);
         g_return_if_fail (GDM_IS_DISPLAY_STORE (object));
 
         store = GDM_DISPLAY_STORE (object);
 
-        g_return_if_fail (store->priv != NULL);
-
-        g_hash_table_destroy (store->priv->displays);
+        g_hash_table_destroy (store->displays);
 
         G_OBJECT_CLASS (gdm_display_store_parent_class)->finalize (object);
 }
