@@ -25,6 +25,7 @@
  */
 #include "config.h"
 #include "gdm-session-solaris-auditor.h"
+#include "gdm-common.h"
 
 #include <syslog.h>
 #include <security/pam_appl.h>
@@ -38,7 +39,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
-struct GdmSessionSolarisAuditor
+struct _GdmSessionSolarisAuditor
 {
         GdmSessionAuditor parent;
 
@@ -322,11 +323,13 @@ static void
 on_username_set (GdmSessionSolarisAuditor *auditor)
 {
         char          *username;
-        struct passwd *passwd_entry;
+        struct passwd *passwd_entry = NULL;
 
         g_object_get (G_OBJECT (auditor), "username", &username, NULL);
 
-        gdm_get_pwent_for_name (username, &passwd_entry);
+        if (username != NULL) {
+                gdm_get_pwent_for_name (username, &passwd_entry);
+        }
 
         if (passwd_entry != NULL) {
                 auditor->uid = passwd_entry->pw_uid;
